@@ -3,7 +3,7 @@ use std::env;
 
 use glassbench::*;
 use image::io::Reader;
-use image::{ImageBuffer, Luma, RgbImage, RgbaImage};
+use image::{GrayImage, ImageBuffer, Luma, RgbImage, RgbaImage};
 
 pub fn get_big_rgb_image() -> RgbImage {
     let cur_dir = env::current_dir().unwrap();
@@ -23,7 +23,7 @@ pub fn get_big_rgba_image() -> RgbaImage {
     img.to_rgba8()
 }
 
-pub fn get_big_luma_image() -> ImageBuffer<Luma<u16>, Vec<u16>> {
+pub fn get_big_luma16_image() -> ImageBuffer<Luma<u16>, Vec<u16>> {
     let cur_dir = env::current_dir().unwrap();
     let img = Reader::open(cur_dir.join("data/nasa-4928x3279.png"))
         .unwrap()
@@ -32,6 +32,15 @@ pub fn get_big_luma_image() -> ImageBuffer<Luma<u16>, Vec<u16>> {
     img.to_luma16()
 }
 
+pub fn get_big_luma8_image() -> GrayImage {
+    let cur_dir = env::current_dir().unwrap();
+    let img = Reader::open(cur_dir.join("data/nasa-4928x3279.png"))
+        .unwrap()
+        .decode()
+        .unwrap();
+    img.to_luma8()
+}
+
 pub fn get_small_rgba_image() -> RgbaImage {
     let cur_dir = env::current_dir().unwrap();
     let img = Reader::open(cur_dir.join("data/nasa-852x567.png"))
