@@ -334,7 +334,7 @@ unsafe fn horiz_convolution_8u(
 
 #[inline]
 #[target_feature(enable = "avx2")]
-pub(crate) unsafe fn vert_convolution_8u(
+unsafe fn vert_convolution_8u(
     src_img: &TypedImageView<U8x4>,
     dst_row: &mut [u32],
     coeffs: &[i16],
@@ -478,8 +478,8 @@ pub(crate) unsafe fn vert_convolution_8u(
             // Load two coefficients at once
             let mmk = simd_utils::ptr_i16_to_set1_epi32(coeffs, y as usize);
 
-            let source1 = simd_utils::mm_cvtsi32_si128(s_row1, x); // top line
-            let source2 = simd_utils::mm_cvtsi32_si128(s_row2, x); // bottom line
+            let source1 = simd_utils::mm_cvtsi32_si128_from_u32(s_row1, x); // top line
+            let source2 = simd_utils::mm_cvtsi32_si128_from_u32(s_row2, x); // bottom line
 
             let source = _mm_unpacklo_epi8(source1, source2);
             let pix = _mm_unpacklo_epi8(source, _mm_setzero_si128());
